@@ -1,4 +1,4 @@
-## Copyright (C) 2007, 2008 David Bateman
+## Copyright (C) 2007-2012 David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -17,10 +17,18 @@
 ## <http://www.gnu.org/licenses/>.
 
 function interpimages (nm, typ)
-  bury_output ();
+  graphics_toolkit ("gnuplot");
+  set_print_size ();
+  hide_output ();
   if (strcmp (typ, "png"))
     set (0, "defaulttextfontname", "*");
   endif
+  if (strcmp (typ, "eps"))
+    d_typ = "-depsc2";
+  else
+    d_typ = cstrcat ("-d", typ);
+  endif
+
   if (strcmp (typ, "txt"))
     image_as_txt (nm);
   elseif (strcmp (nm, "interpft"))
@@ -30,9 +38,9 @@ function interpimages (nm, typ)
     y = sin (4*t + 0.3) .* cos (3*t - 0.1);
     yp = sin (4*ti + 0.3) .* cos (3*ti - 0.1);
     plot (ti, yp, 'g', ti, interp1(t, y, ti, 'spline'), 'b', ...
-	  ti, interpft (y, k), 'c', t, y, 'r+');
-    legend ('sin(4t+0.3)cos(3t-0.1','spline','interpft','data');
-    print (cstrcat (nm, ".", typ), cstrcat ("-d", typ))
+          ti, interpft (y, k), 'c', t, y, 'r+');
+    legend ('sin(4t+0.3)cos(3t-0.1)','spline','interpft','data');
+    print (cstrcat (nm, ".", typ), d_typ)
   elseif (strcmp (nm, "interpn"))
     x = y = z = -1:1;
     f = @(x,y,z) x.^2 - y - z.^2;
@@ -42,7 +50,7 @@ function interpimages (nm, typ)
     [xxi, yyi, zzi] = ndgrid (xi, yi, zi);
     vi = interpn(x, y, z, v, xxi, yyi, zzi, 'spline');
     mesh (zi, yi, squeeze (vi(1,:,:)));
-    print (cstrcat (nm, ".", typ), cstrcat ("-d", typ))
+    print (cstrcat (nm, ".", typ), d_typ)
   elseif (strcmp (nm, "interpderiv1"))
     t = -2:2;
     dt = 1;
@@ -53,7 +61,7 @@ function interpimages (nm, typ)
     yp = interp1(t,y,ti,'pchip');
     plot (ti, ys,'r-', ti, yp,'g-');
     legend('spline','pchip', 4);
-    print (cstrcat (nm, ".", typ), cstrcat ("-d", typ))
+    print (cstrcat (nm, ".", typ), d_typ)
   elseif (strcmp (nm, "interpderiv2"))
     t = -2:2;
     dt = 1;
@@ -64,15 +72,24 @@ function interpimages (nm, typ)
     ddyp = diff(diff(interp1(t,y,ti,'pchip'))./dti)./dti;
     plot (ti(2:end-1),ddys,'r*', ti(2:end-1),ddyp,'g+');
     legend('spline','pchip');
-    print (cstrcat (nm, ".", typ), cstrcat ("-d", typ))
+    print (cstrcat (nm, ".", typ), d_typ)
   endif
-  bury_output ();  
+  hide_output ();  
+endfunction
+
+function set_print_size ()
+  image_size = [5.0, 3.5]; # in inches, 16:9 format
+  border = 0;              # For postscript use 50/72
+  set (0, "defaultfigurepapertype", "<custom>");
+  set (0, "defaultfigurepaperorientation", "landscape");
+  set (0, "defaultfigurepapersize", image_size + 2*border);
+  set (0, "defaultfigurepaperposition", [border, border, image_size]);
 endfunction
 
 ## Use this function before plotting commands and after every call to
 ## print since print() resets output to stdout (unfortunately, gnpulot
 ## can't pop output as it can the terminal type).
-function bury_output ()
+function hide_output ()
   f = figure (1);
   set (f, "visible", "off");
 endfunction
