@@ -1,7 +1,6 @@
 /*
 
-Copyright (C) 1993, 1994, 1995, 1996, 1997, 2000, 2002, 2003, 2004,
-              2005, 2006, 2007 John W. Eaton
+Copyright (C) 1993-2012 John W. Eaton
 
 This file is part of Octave.
 
@@ -24,7 +23,7 @@ along with Octave; see the file COPYING.  If not, see
 #if !defined (octave_CollocWt_h)
 #define octave_CollocWt_h 1
 
-#include <iostream>
+#include <iosfwd>
 
 #include "dMatrix.h"
 #include "dColVector.h"
@@ -37,46 +36,49 @@ public:
 
   CollocWt (void)
     : n (0), inc_left (0), inc_right (0), lb (0.0), rb (1.0),
-      Alpha (0.0), Beta (0.0), r (), q (), A (), B (), initialized (0) { }
+      Alpha (0.0), Beta (0.0), r (), q (), A (), B (), initialized (false) { }
 
   CollocWt (octave_idx_type nc, octave_idx_type il, octave_idx_type ir)
     : n (nc), inc_left (il), inc_right (ir), lb (0.0), rb (1.0),
-      Alpha (0.0), Beta (0.0), r (), q (), A (), B (), initialized (0) { }
+      Alpha (0.0), Beta (0.0), r (), q (), A (), B (), initialized (false) { }
 
-  CollocWt (octave_idx_type nc, octave_idx_type il, octave_idx_type ir, double l, double rr)
+  CollocWt (octave_idx_type nc, octave_idx_type il, octave_idx_type ir,
+            double l, double rr)
     : n (nc), inc_left (il), inc_right (ir), lb (l), rb (rr),
-      Alpha (0.0), Beta (0.0), r (), q (), A (), B (), initialized (0) { }
+      Alpha (0.0), Beta (0.0), r (), q (), A (), B (), initialized (false) { }
 
-  CollocWt (octave_idx_type nc, double a, double b, octave_idx_type il, octave_idx_type ir)
+  CollocWt (octave_idx_type nc, double a, double b, octave_idx_type il,
+            octave_idx_type ir)
     : n (nc), inc_left (il), inc_right (ir), lb (0.0), rb (1.0),
-      Alpha (a), Beta (b), initialized (0) { }
+      Alpha (a), Beta (b), r (), q (), A (), B (), initialized (false) { }
 
-  CollocWt (octave_idx_type nc, double a, double b, octave_idx_type il, octave_idx_type ir,
-		      double ll, double rr)  
+  CollocWt (octave_idx_type nc, double a, double b, octave_idx_type il,
+            octave_idx_type ir,
+                      double ll, double rr)
     : n (nc), inc_left (il), inc_right (ir), lb (ll), rb (rr),
-      Alpha (a), Beta (b), r (), q (), A (), B (), initialized (0) { }
+      Alpha (a), Beta (b), r (), q (), A (), B (), initialized (false) { }
 
   CollocWt (const CollocWt& a)
     : n (a.n), inc_left (a.inc_left), inc_right (a.inc_right),
       lb (a.lb), rb (a.rb), Alpha (a.Alpha), Beta (a.Beta),
       r (a.r), q (a.q), A (a.A), B (a.B),
-      initialized (a.initialized) { } 
+      initialized (a.initialized) { }
 
   CollocWt& operator = (const CollocWt& a)
     {
       if (this != &a)
-	{
-	  n = a.n;
-	  inc_left = a.inc_left;
-	  inc_right = a.inc_right;
-	  lb = a.lb;
-	  rb = a.rb;
-	  r = a.r;
-	  q = a.q;
-	  A = a.A;
-	  B = a.B;
-	  initialized = a.initialized;
-	}
+        {
+          n = a.n;
+          inc_left = a.inc_left;
+          inc_right = a.inc_right;
+          lb = a.lb;
+          rb = a.rb;
+          r = a.r;
+          q = a.q;
+          A = a.A;
+          B = a.B;
+          initialized = a.initialized;
+        }
       return *this;
     }
 
@@ -85,21 +87,21 @@ public:
   CollocWt& resize (octave_idx_type nc)
     {
       n = nc;
-      initialized = 0;
+      initialized = false;
       return *this;
     }
 
   CollocWt& add_left (void)
     {
       inc_left = 1;
-      initialized = 0;
+      initialized = false;
       return *this;
     }
 
   CollocWt& delete_left (void)
     {
       inc_left = 0;
-      initialized = 0;
+      initialized = false;
       return *this;
     }
 
@@ -108,14 +110,14 @@ public:
   CollocWt& add_right (void)
     {
       inc_right = 1;
-      initialized = 0;
+      initialized = false;
       return *this;
     }
 
   CollocWt& delete_right (void)
     {
       inc_right = 0;
-      initialized = 0;
+      initialized = false;
       return *this;
     }
 
@@ -124,14 +126,14 @@ public:
   CollocWt& set_alpha (double val)
     {
       Alpha = val;
-      initialized = 0;
+      initialized = false;
       return *this;
     }
 
   CollocWt& set_beta (double val)
     {
       Beta = val;
-      initialized = 0;
+      initialized = false;
       return *this;
     }
 
@@ -178,7 +180,7 @@ protected:
   Matrix A;
   Matrix B;
 
-  int initialized;
+  bool initialized;
 
   void init (void);
 
@@ -186,9 +188,3 @@ protected:
 };
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
