@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996, 1997, 2000, 2004, 2005, 2006, 2007, 2008 John W. Eaton
+Copyright (C) 1996-2012 John W. Eaton
 
 This file is part of Octave.
 
@@ -64,11 +64,11 @@ public:
   static data_type string_to_data_type (const std::string& s);
 
   static void string_to_data_type (const std::string& s, int& block_size,
-				   data_type& input_type,
-				   data_type& output_type);
+                                   data_type& input_type,
+                                   data_type& output_type);
 
   static void string_to_data_type (const std::string& s, int& block_size,
-				   data_type& output_type);
+                                   data_type& output_type);
 
   static std::string data_type_as_string (data_type dt);
 };
@@ -92,39 +92,37 @@ enum save_type
   };
 
 extern OCTAVE_API void
-do_double_format_conversion (void *data, int len,
-			     oct_mach_info::float_format from_fmt,
-			     oct_mach_info::float_format to_fmt
-			       = oct_mach_info::native_float_format ());
+do_double_format_conversion (void *data, octave_idx_type len,
+                             oct_mach_info::float_format from_fmt,
+                             oct_mach_info::float_format to_fmt
+                               = oct_mach_info::native_float_format ());
 
 extern OCTAVE_API void
-do_float_format_conversion (void *data, int len,
-			    oct_mach_info::float_format from_fmt,
-			    oct_mach_info::float_format to_fmt
-			      = oct_mach_info::native_float_format ());
+do_float_format_conversion (void *data, octave_idx_type len,
+                            oct_mach_info::float_format from_fmt,
+                            oct_mach_info::float_format to_fmt
+                              = oct_mach_info::native_float_format ());
 
 extern OCTAVE_API void
-do_float_format_conversion (void *data, size_t sz, int len,
-			    oct_mach_info::float_format from_fmt,
-			    oct_mach_info::float_format to_fmt
-			      = oct_mach_info::native_float_format ());
+do_float_format_conversion (void *data, size_t sz, octave_idx_type len,
+                            oct_mach_info::float_format from_fmt,
+                            oct_mach_info::float_format to_fmt
+                              = oct_mach_info::native_float_format ());
 
 extern OCTAVE_API void
-read_doubles (std::istream& is, double *data, save_type type, int len,
-	      bool swap, oct_mach_info::float_format fmt);
-extern OCTAVE_API void
-write_doubles (std::ostream& os, const double *data, save_type type, int len);
+read_doubles (std::istream& is, double *data, save_type type,
+              octave_idx_type len, bool swap, oct_mach_info::float_format fmt);
 
 extern OCTAVE_API void
-read_floats (std::istream& is, float *data, save_type type, int len,
-	      bool swap, oct_mach_info::float_format fmt);
+write_doubles (std::ostream& os, const double *data, save_type type,
+               octave_idx_type len);
+
 extern OCTAVE_API void
-write_floats (std::ostream& os, const float *data, save_type type, int len);
+read_floats (std::istream& is, float *data, save_type type,
+             octave_idx_type len, bool swap, oct_mach_info::float_format fmt);
+
+extern OCTAVE_API void
+write_floats (std::ostream& os, const float *data, save_type type,
+              octave_idx_type len);
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
