@@ -1,4 +1,4 @@
-## Copyright (C) 2000, 2006, 2007, 2009 Kai Habel
+## Copyright (C) 2000-2012 Kai Habel
 ## Copyright (C) 2008 Marco Caliari
 ##
 ## This file is part of Octave.
@@ -18,13 +18,13 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {@var{l} =} legendre (@var{n}, @var{x})
+## @deftypefn  {Function File} {@var{l} =} legendre (@var{n}, @var{x})
 ## @deftypefnx {Function File} {@var{l} =} legendre (@var{n}, @var{x}, @var{normalization})
-## Compute the Legendre function of degree @var{n} and order 
-## @var{m} = 0 @dots{} N.  The optional argument, @var{normalization}, 
+## Compute the Legendre function of degree @var{n} and order
+## @var{m} = 0 @dots{} N@.  The optional argument, @var{normalization},
 ## may be one of @code{"unnorm"}, @code{"sch"}, or @code{"norm"}.
-## The default is @code{"unnorm"}.  The value of @var{n} must be a 
-## non-negative scalar integer.  
+## The default is @code{"unnorm"}.  The value of @var{n} must be a
+## non-negative scalar integer.
 ##
 ## If the optional argument @var{normalization} is missing or is
 ## @code{"unnorm"}, compute the Legendre function of degree @var{n} and
@@ -33,6 +33,13 @@
 ##
 ## The Legendre Function of degree @var{n} and order @var{m}:
 ##
+## @tex
+## $$
+## P^m_n(x) = (-1)^m (1-x^2)^{m/2}{d^m\over {dx^m}}P_n (x)
+## $$
+## @end tex
+## @ifnottex
+##
 ## @example
 ## @group
 ##  m        m       2  m/2   d^m
@@ -41,9 +48,18 @@
 ## @end group
 ## @end example
 ##
+## @end ifnottex
+##
 ## @noindent
 ## with Legendre polynomial of degree @var{n}:
 ##
+## @tex
+## $$
+## P(x) = {1\over{2^n n!}}\biggl({d^n\over{dx^n}}(x^2 - 1)^n\biggr)
+## $$
+## @end tex
+## @ifnottex
+##
 ## @example
 ## @group
 ##           1     d^n   2    n
@@ -52,6 +68,8 @@
 ## @end group
 ## @end example
 ##
+## @end ifnottex
+##
 ## @noindent
 ## @code{legendre (3, [-1.0, -0.9, -0.8])} returns the matrix:
 ##
@@ -62,17 +80,24 @@
 ## m=0 | -1.00000 | -0.47250 | -0.08000
 ## m=1 |  0.00000 | -1.99420 | -1.98000
 ## m=2 |  0.00000 | -2.56500 | -4.32000
-## m=3 |  0.00000 | -1.24229 | -3.24000 
+## m=3 |  0.00000 | -1.24229 | -3.24000
 ## @end group
 ## @end example
 ##
-## If the optional argument @code{normalization} is @code{"sch"}, 
+## If the optional argument @code{normalization} is @code{"sch"},
 ## compute the Schmidt semi-normalized associated Legendre function.
 ## The Schmidt semi-normalized associated Legendre function is related
 ## to the unnormalized Legendre functions by the following:
 ##
 ## For Legendre functions of degree n and order 0:
 ##
+## @tex
+## $$
+## SP^0_n (x) = P^0_n (x)
+## $$
+## @end tex
+## @ifnottex
+##
 ## @example
 ## @group
 ##   0       0
@@ -81,8 +106,17 @@
 ## @end group
 ## @end example
 ##
+## @end ifnottex
+##
 ## For Legendre functions of degree n and order m:
 ##
+## @tex
+## $$
+## SP^m_n (x) = P^m_n (x)(-1)^m\biggl({2(n-m)!\over{(n+m)!}}\biggl)^{0.5}
+## $$
+## @end tex
+## @ifnottex
+##
 ## @example
 ## @group
 ##   m       m          m    2(n-m)! 0.5
@@ -91,20 +125,31 @@
 ## @end group
 ## @end example
 ##
-## If the optional argument @var{normalization} is @code{"norm"}, 
+## @end ifnottex
+##
+## If the optional argument @var{normalization} is @code{"norm"},
 ## compute the fully normalized associated Legendre function.
 ## The fully normalized associated Legendre function is related
 ## to the unnormalized Legendre functions by the following:
 ##
 ## For Legendre functions of degree @var{n} and order @var{m}
 ##
+## @tex
+## $$
+## NP^m_n (x) = P^m_n (x)(-1)^m\biggl({(n+0.5)(n-m)!\over{(n+m)!}}\biggl)^{0.5}
+## $$
+## @end tex
+## @ifnottex
+##
 ## @example
 ## @group
 ##   m       m          m    (n+0.5)(n-m)! 0.5
 ## NP (x) = P (x) * (-1)  * [-------------]
-##   n       n                   (n+m)!    
+##   n       n                   (n+m)!
 ## @end group
 ## @end example
+##
+## @end ifnottex
 ## @end deftypefn
 
 ## Author: Marco Caliari <marco.caliari@univr.it>
@@ -117,20 +162,20 @@ function retval = legendre (n, x, normalization)
     print_usage ();
   endif
 
+  if (!isscalar (n) || n < 0 || n != fix (n))
+    error ("legendre: N must be a non-negative scalar integer");
+  endif
+
+  if (!isreal (x) || any (x(:) < -1 | x(:) > 1))
+    error ("legendre: X must be real-valued vector in the range -1 <= X <= 1");
+  endif
+
   if (nargin == 3)
     normalization = lower (normalization);
   else
     normalization = "unnorm";
   endif
 
-  if (! isscalar (n) || n < 0 || n != fix (n))
-    error ("legendre: n must be a non-negative scalar integer");
-  endif
-
-  if (! isvector (x) || any (x < -1 || x > 1))
-    error ("legendre: x must be vector in range -1 <= x <= 1");
-  endif
-
   switch (normalization)
     case "norm"
       scale = sqrt (n+0.5);
@@ -139,10 +184,10 @@ function retval = legendre (n, x, normalization)
     case "unnorm"
       scale = 1;
     otherwise
-      error ("legendre: expecting normalization option to be \"norm\", \"sch\", or \"unnorm\"");
+      error ('legendre: expecting NORMALIZATION option to be "norm", "sch", or "unnorm"');
   endswitch
 
-  scale = scale * ones (1, numel (x));
+  scale = scale * ones (size (x));
 
   ## Based on the recurrence relation below
   ##            m                 m              m
@@ -151,9 +196,10 @@ function retval = legendre (n, x, normalization)
   ## http://en.wikipedia.org/wiki/Associated_Legendre_function
 
   overflow = false;
+  retval = zeros([n+1, size(x)]);
   for m = 1:n
     lpm1 = scale;
-    lpm2 = (2*m-1) .* x .* scale;      
+    lpm2 = (2*m-1) .* x .* scale;
     lpm3 = lpm2;
     for k = m+1:n
       lpm3a = (2*k-1) .* x .* lpm2;
@@ -169,7 +215,7 @@ function retval = legendre (n, x, normalization)
         endif
       endif
     endfor
-    retval(m,:) = lpm3;
+    retval(m,:) = lpm3(:);
     if (strcmp (normalization, "unnorm"))
       scale = -scale * (2*m-1);
     else
@@ -179,7 +225,12 @@ function retval = legendre (n, x, normalization)
     scale = scale .* sqrt(1-x.^2);
   endfor
 
-  retval(n+1,:) = scale;
+  retval(n+1,:) = scale(:);
+
+  if (isvector (x))
+  ## vector case is special
+    retval = reshape (retval, n + 1, length (x));
+  endif
 
   if (strcmp (normalization, "sch"))
     retval(1,:) = retval(1,:) / sqrt (2);
@@ -192,6 +243,7 @@ function retval = legendre (n, x, normalization)
 
 endfunction
 
+
 %!test
 %! result = legendre (3, [-1.0 -0.9 -0.8]);
 %! expected = [
@@ -230,8 +282,34 @@ endfunction
 %!test
 %! result = legendre (150, 0);
 %! ## This agrees with Matlab's result.
-%! assert (result(end), 3.7532741115719e+306, 0.0000000000001e+306)
+%! assert (result(end), 3.7532741115719e+306, 0.0000000000001e+306);
 
 %!test
 %! result = legendre (0, 0:0.1:1);
-%! assert (result, full(ones(1,11)))
+%! assert (result, full(ones(1,11)));
+
+%!test
+%! result = legendre (3, [-1,0,1;1,0,-1]);
+%! ## Test matrix input
+%! expected(:,:,1) = [-1,1;0,0;0,0;0,0];
+%! expected(:,:,2) = [0,0;1.5,1.5;0,0;-15,-15];
+%! expected(:,:,3) = [1,-1;0,0;0,0;0,0];
+%! assert (result, expected);
+
+%!test
+%! result = legendre (3, [-1,0,1;1,0,-1]');
+%! expected(:,:,1) = [-1,0,1;0,1.5,0;0,0,0;0,-15,0];
+%! expected(:,:,2) = [1,0,-1;0,1.5,0;0,0,0;0,-15,0];
+%! assert (result, expected);
+
+%% Check correct invocation
+%!error legendre ();
+%!error legendre (1);
+%!error legendre (1,2,3,4);
+%!error legendre ([1, 2], [-1, 0, 1]);
+%!error legendre (-1, [-1, 0, 1]);
+%!error legendre (1.1, [-1, 0, 1]);
+%!error legendre (1, [-1+i, 0, 1]);
+%!error legendre (1, [-2, 0, 1]);
+%!error legendre (1, [-1, 0, 2]);
+%!error legendre (1, [-1, 0, 1], "badnorm");
