@@ -1,5 +1,4 @@
-## Copyright (C) 1996, 1997, 1998, 1999, 2000, 2002, 2005, 2006, 2007,
-##               2008, 2009 Kurt Hornik
+## Copyright (C) 1996-2012 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -18,14 +17,14 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} manova (@var{y}, @var{g})
+## @deftypefn {Function File} {} manova (@var{x}, @var{g})
 ## Perform a one-way multivariate analysis of variance (MANOVA).  The
 ## goal is to test whether the p-dimensional population means of data
 ## taken from @var{k} different groups are all equal.  All data are
 ## assumed drawn independently from p-dimensional normal distributions
 ## with the same covariance matrix.
 ##
-## The data matrix is given by @var{y}.  As usual, rows are observations
+## The data matrix is given by @var{x}.  As usual, rows are observations
 ## and columns are variables.  The vector @var{g} specifies the
 ## corresponding group labels (e.g., numbers from 1 to @var{k}).
 ##
@@ -35,26 +34,26 @@
 
 ## Three test statistics (Wilks, Hotelling-Lawley, and Pillai-Bartlett)
 ## and corresponding approximate p-values are calculated and displayed.
-## (Currently NOT because the f_cdf respectively betai code is too bad.)
+## (Currently NOT because the fcdf respectively betai code is too bad.)
 
 ## Author: TF <Thomas.Fuereder@ci.tuwien.ac.at>
 ## Adapted-By: KH <Kurt.Hornik@wu-wien.ac.at>
 ## Description: One-way multivariate analysis of variance (MANOVA)
 
-function manova (Y, g)
+function manova (x, g)
 
   if (nargin != 2)
     print_usage ();
   endif
 
-  if (isvector (Y))
+  if (isvector (x))
     error ("manova: Y must not be a vector");
   endif
 
-  [n, p] = size (Y);
+  [n, p] = size (x);
 
   if (!isvector (g) || (length (g) != n))
-    error ("manova: g must be a vector of length rows (Y)");
+    error ("manova: G must be a vector of length rows (Y)");
   endif
 
   s = sort (g);
@@ -67,13 +66,13 @@ function manova (Y, g)
     group_label = s ([1, (reshape (i, 1, k - 1) + 1)]);
   endif
 
-  Y = Y - ones (n, 1) * mean (Y);
-  SST = Y' * Y;
+  x = x - ones (n, 1) * mean (x);
+  SST = x' * x;
 
   s = zeros (1, p);
   SSB = zeros (p, p);
   for i = 1 : k;
-    v = Y (find (g == group_label (i)), :);
+    v = x (find (g == group_label (i)), :);
     s = sum (v);
     SSB = SSB + s' * s / rows (v);
   endfor
@@ -95,20 +94,20 @@ function manova (Y, g)
 
   Lambda = prod (1 ./ (1 + l));
 
-  delta = n_w + n_b - (p + n_b + 1) / 2
-  df_num = p * n_b
-  W_pval_1 = 1 - chisquare_cdf (- delta * log (Lambda), df_num);
+  delta = n_w + n_b - (p + n_b + 1) / 2;
+  df_num = p * n_b;
+  W_pval_1 = 1 - chi2cdf (- delta * log (Lambda), df_num);
 
   if (p < 3)
     eta = p;
   else
-    eta = sqrt ((p^2 * n_b^2 - 4) / (p^2 + n_b^2 - 5))
+    eta = sqrt ((p^2 * n_b^2 - 4) / (p^2 + n_b^2 - 5));
   endif
 
-  df_den = delta * eta - df_num / 2 + 1
+  df_den = delta * eta - df_num / 2 + 1;
 
-  WT = exp (- log (Lambda) / eta) - 1
-  W_pval_2 = 1 - f_cdf (WT * df_den / df_num, df_num, df_den);
+  WT = exp (- log (Lambda) / eta) - 1;
+  W_pval_2 = 1 - fcdf (WT * df_den / df_num, df_num, df_den);
 
   if (0)
 
@@ -124,7 +123,7 @@ function manova (Y, g)
     df_num = theta * (2 * u + theta + 1);
     df_den = 2 * (theta * v + 1);
 
-    HL_pval = 1 - f_cdf (HL * df_den / df_num, df_num, df_den);
+    HL_pval = 1 - fcdf (HL * df_den / df_num, df_num, df_den);
 
     ## Pillai-Bartlett
     ## ===============
@@ -132,7 +131,7 @@ function manova (Y, g)
     PB = sum (l ./ (1 + l));
 
     df_den = theta * (2 * v + theta + 1);
-    PB_pval = 1 - f_cdf (PB * df_den / df_num, df_num, df_den);
+    PB_pval = 1 - fcdf (PB * df_den / df_num, df_num, df_den);
 
     printf ("\n");
     printf ("One-way MANOVA Table:\n");
